#!/usr/bin/bash

(( ${EUID} != 0 )) &&
  { echo >&2 "This script should be run as root!"; exit 1; }

# -------------------------------------------------------------------------------------------------------------------- #
# Get options.
# -------------------------------------------------------------------------------------------------------------------- #

OPTIND=1

while getopts "d:h" opt; do
  case ${opt} in
    d)
      device="${OPTARG}"
      ;;
    h|*)
      echo "-d [device (sda / sdb / sdc)]"
      exit 2
      ;;
    \?)
      echo "Invalid option: -${OPTARG}."
      exit 1
      ;;
    :)
      echo "Option -${OPTARG} requires an argument."
      exit 1
      ;;
  esac
done

shift $(( ${OPTIND} - 1 ))

[[ -z "${device}" ]] && exit 1

# -------------------------------------------------------------------------------------------------------------------- #
# -----------------------------------------------------< SCRIPT >----------------------------------------------------- #
# -------------------------------------------------------------------------------------------------------------------- #

# -------------------------------------------------------------------------------------------------------------------- #
# Install apps.
# -------------------------------------------------------------------------------------------------------------------- #

for app in parted sgdisk; do
  if [[ -x "$(command -v ${app})" ]]; then
    dnf install -y ${app}
  fi
done

# -------------------------------------------------------------------------------------------------------------------- #
# Get apps.
# -------------------------------------------------------------------------------------------------------------------- #

# SGDisk.
sgdisk=$( command -v sgdisk )

# -------------------------------------------------------------------------------------------------------------------- #
# Clearing MBR / GPT.
# -------------------------------------------------------------------------------------------------------------------- #

${sgdisk} -Z /dev/${device}

# -------------------------------------------------------------------------------------------------------------------- #
# Create storage.
# -------------------------------------------------------------------------------------------------------------------- #

${parted} -s -a optimal -- /dev/${device} mklabel gpt mkpart primary 0% 100%
mkfs.xfs /dev/${device}1

# -------------------------------------------------------------------------------------------------------------------- #
# Exit.
# -------------------------------------------------------------------------------------------------------------------- #

exit 0
