#!/usr/bin/bash

(( ${EUID} != 0 )) &&
  { echo >&2 "This script should be run as root!"; exit 1; }

# -------------------------------------------------------------------------------------------------------------------- #
# Get options.
# -------------------------------------------------------------------------------------------------------------------- #

OPTIND=1

while getopts "f:d:h" opt; do
  case ${opt} in
    f)
      file="${OPTARG}"
      ;;
    d)
      device="${OPTARG}"
      ;;
    h|*)
      echo "-f [file] -d [device (sda / sdb / sdc)]"
      exit 2
      ;;
    \?)
      echo "Invalid option: -${OPTARG}."
      exit 1
      ;;
    :)
      echo "Option -${OPTARG} requires an argument."
      exit 1
      ;;
  esac
done

shift $(( ${OPTIND} - 1 ))

[[ -z "${file}" ]] || [[ -z "${device}" ]] && exit 1
[[ ! -f "${file}" ]] || [[ ! -e "/dev/${device}" ]] && exit 1

# -------------------------------------------------------------------------------------------------------------------- #
# -----------------------------------------------------< SCRIPT >----------------------------------------------------- #
# -------------------------------------------------------------------------------------------------------------------- #

# -------------------------------------------------------------------------------------------------------------------- #
# Set apps.
# -------------------------------------------------------------------------------------------------------------------- #

# Checksum.
sum=$( command -v sha256sum )

# SGDisk.
sgdisk=$( command -v sgdisk )

# Sleep time.
sleep="5"

# -------------------------------------------------------------------------------------------------------------------- #
# Run checksum.
# -------------------------------------------------------------------------------------------------------------------- #

echo "--- Checksum: ${file}"
${sum} ${file}
echo "" && sleep ${sleep}

# -------------------------------------------------------------------------------------------------------------------- #
# Unmount and clean USB drive.
# -------------------------------------------------------------------------------------------------------------------- #

echo "--- Unmount & clean: /dev/${device}"
umount /dev/${device}*
${sgdisk} -Z /dev/${device}
echo "" && sleep ${sleep}

# -------------------------------------------------------------------------------------------------------------------- #
# Burn image to USB drive.
# -------------------------------------------------------------------------------------------------------------------- #

echo "--- Burn: ${file}"
dd if=${file} of=/dev/${device} bs=4M oflag=direct status=progress; sync
echo "" && sleep ${sleep}

# -------------------------------------------------------------------------------------------------------------------- #
# Eject USB drive.
# -------------------------------------------------------------------------------------------------------------------- #

echo "--- Eject: /dev/${device}"
eject /dev/${device}
echo "" && sleep ${sleep}

# -------------------------------------------------------------------------------------------------------------------- #
# Exit.
# -------------------------------------------------------------------------------------------------------------------- #

exit 0
